@@ -1,6 +1,8 @@
 pub mod common;
 pub mod mpmc;
+pub mod option;
 pub mod spsc;
 
 pub use mpmc::Mpmc;
+pub use option::AtomicOption;
 pub use spsc::Spsc;
